@@ -180,6 +180,15 @@ Suitable implementations include Bio::DB::SeqFeature::Store (part of
 BioPerl) and Bio::DB::Sam::Fai, part of the Bio::SamTools package. You
 are of course welcome to implement your own Fasta object.
 
+When opening a remote file on an FTP or HTTP server, the directory
+returned by Bio::DB::BigFile->udcGetDefaultDir must be writable
+(usually '/tmp/udcCache'). The new() method will attempt to catch the
+case in which this directory is not writable and instead set the cache
+to /tmp/udcCache_###, where ### is the current username. For better
+control over this behavior, you may set the environment variable
+UDC_CACHEDIR before creating the BigWig file.
+
+
 =back
 
 =head1 OBJECT METHODS
@@ -549,6 +558,8 @@ sub new {
     unless ($self->is_remote($bb_path)) {
 	-e $bb_path or croak "$bb_path does not exist";
 	-r _  or croak "is not readable";
+    } else {
+	Bio::DB::BigFile->set_udc_defaults;
     }
 
     my $bb = Bio::DB::BigFile->bigBedFileOpen($bb_path)
