@@ -420,6 +420,7 @@ sub get_seq_stream {
     } else {
 	%options = @_;
     }
+    $options{-type} ||= $options{-types};
 
     my @ids = keys %{$self->{bigwigs}};
     @ids    = $self->_filter_ids_by_type($options{-type},           \@ids) if $options{-type};
@@ -764,6 +765,7 @@ sub read_index {
 
     while (<$f>) {
 	chomp;
+	s/\s+$//;   # strip whitespace at ends of lines
 	# strip right-column comments unless they look like colors or html fragments
 	s/\s*\#.*$// unless /\#[0-9a-f]{6,8}\s*$/i || /\w+\#\w+/ || /\w+\"*\s*\#\d+$/;   
 	if (/^\[([^\]]+)\]/) {  # beginning of a configuration section
